Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(925)

Unified Diff: components/omnibox/browser/autocomplete_result.h

Issue 2873423002: Omnibox UI Experiments: Add flag to change max autocomplete matches. (Closed)
Patch Set: fix merge' Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/omnibox/browser/autocomplete_result.h
diff --git a/components/omnibox/browser/autocomplete_result.h b/components/omnibox/browser/autocomplete_result.h
index 499d97d5f5ce44e8cef9aac76e7ab7d322df78d1..95b0b5e9fa2899b36a40ee2bd1870017aa87f997 100644
--- a/components/omnibox/browser/autocomplete_result.h
+++ b/components/omnibox/browser/autocomplete_result.h
@@ -59,7 +59,7 @@ class AutocompleteResult {
};
// Max number of matches we'll show from the various providers.
- static const size_t kMaxMatches;
+ static size_t GetMaxMatches();
AutocompleteResult();
~AutocompleteResult();
@@ -77,7 +77,7 @@ class AutocompleteResult {
const ACMatches& matches);
// Removes duplicates, puts the list in sorted order and culls to leave only
// the best kMaxMatches matches. Sets the default match to the best match
// and updates the alternate nav URL.
void SortAndCull(const AutocompleteInput& input,
TemplateURLService* template_url_service);
@@ -77,7 +77,7 @@ class AutocompleteResult {
const ACMatches& matches);
// Removes duplicates, puts the list in sorted order and culls to leave only
- // the best kMaxMatches matches. Sets the default match to the best match
+ // the best GetMaxMatches() matches. Sets the default match to the best match
// and updates the alternate nav URL.
void SortAndCull(const AutocompleteInput& input,
« no previous file with comments | « chrome/browser/ui/views/omnibox/omnibox_popup_contents_view.cc ('k') | components/omnibox/browser/autocomplete_result.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698